@@ -542,7 +542,7 @@ socks4_reply_handler (GNetworkIOChannelProxy * proxy, GIOCondition cond, gpointe
       bytes_done = 0;
       do
 	{
-	  gint tmp = 0;
+	  gsize tmp = 0;
 
 	  status = g_io_channel_read_chars (G_IO_CHANNEL (proxy), (gchar *) & data,
 					    sizeof (Socks4Data), &tmp, &error);
@@ -682,7 +682,7 @@ traverse_socks4_proxy (GNetworkIOChannelProxy * proxy)
   ip_address = gnetwork_dns_entry_get_ip_address (proxy->destination);
   if (ip_address != NULL && gnetwork_ip_address_is_ipv4 (ip_address))
     {
-      SOCKS4_DATA (data)->address = GNETWORK_IP_ADDRESS32 (ip_address, 3);
+      SOCKS4_DATA (data)->address = (guint32) GNETWORK_IP_ADDRESS32 (ip_address, 3);
       data = (guchar *) g_malloc (sizeof (Socks4Data) + username_size + 1);
       strcpy (data + sizeof (Socks4Data), username);
       data_size = sizeof (Socks4Data) + username_size;
@@ -699,7 +699,7 @@ traverse_socks4_proxy (GNetworkIOChannelProxy * proxy)
 
       str_size = strlen (str);
 
-      SOCKS4_DATA (data)->address = SOCKS4A_ADDRESS;
+      SOCKS4_DATA (data)->address = (guint32) SOCKS4A_ADDRESS;
       data = (guchar *) g_malloc (sizeof (Socks4Data) + username_size + str_size + 2);
       strcpy (data + sizeof (Socks4Data), username);
       strcpy (data + sizeof (Socks4Data) + username_size, str);
@@ -708,15 +708,16 @@ traverse_socks4_proxy (GNetworkIOChannelProxy * proxy)
       g_free (str);
     }
 
-  SOCKS4_DATA (data)->version = 4;
-  SOCKS4_DATA (data)->command = SOCKS4_COMMAND_LOGIN;
-  SOCKS4_DATA (data)->port = g_htons (proxy->port);
+  SOCKS4_DATA (data)->version = (guint32) 4;
+  SOCKS4_DATA (data)->command = (guint32) SOCKS4_COMMAND_LOGIN;
+  SOCKS4_DATA (data)->port = (guint32) g_htons (proxy->port);
 
   /* Connection request */
   bytes_done = 0;
   do
     {
-      gint tmp = 0;
+      gsize tmp = 0;
+
       status = g_io_channel_write_chars (G_IO_CHANNEL (proxy), data + bytes_done,
 					 data_size - bytes_done, &tmp, &error);
 
@@ -1258,7 +1259,7 @@ traverse_socks5_proxy (GNetworkIOChannelProxy * proxy)
   bytes_done = 0;
   do
     {
-      gint tmp = 0;
+      gsize tmp = 0;
 
       status = g_io_channel_write_chars (G_IO_CHANNEL (proxy), (gchar *) (&data) + bytes_done,
 					 sizeof (Socks5NegotiationData) - bytes_done, &tmp, &error);
